|banner|

|build_status| |license| |coverage| |docs| |CodeQL| |PyPI| |DOI|

BlueETL
=======

Multiple simulations analysis tool.


Introduction
------------

``BlueETL`` is a package that can help analyse multiple simulations in a Simulation Campaign.

It automatically uses `Blue Brain SNAP <https://bluebrainsnap.readthedocs.io/en/stable/>`__ or `BluePy <https://bbpteam.epfl.ch/documentation/projects/bluepy/latest/>`__ to open simulations, circuits, and reports.


Contribution Guidelines
-----------------------

See `<CONTRIBUTING.rst>`__.


Citation
--------

When you use this software, we kindly ask you to cite the following DOI:

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.10286540.svg
   :target: https://doi.org/10.5281/zenodo.10286540


Acknowledgment
--------------

The development of this software was supported by funding to the Blue Brain Project, a research center of the École polytechnique fédérale de Lausanne (EPFL), from the Swiss government’s ETH Board of the Swiss Federal Institutes of Technology.

For license and authors, see `<LICENSE.txt>`__ and `<AUTHORS.txt>`__ respectively.

Copyright © 2023 Blue Brain Project/EPFL


.. |build_status| image:: https://github.com/BlueBrain/blueetl/actions/workflows/run-tox.yml/badge.svg
   :alt: Build Status

.. |license| image:: https://img.shields.io/pypi/l/blueetl
   :target: https://github.com/BlueBrain/blueetl/blob/main/LICENSE.txt
   :alt: License

.. |coverage| image:: https://codecov.io/github/BlueBrain/blueetl/coverage.svg?branch=main
   :target: https://codecov.io/github/BlueBrain/blueetl?branch=main
   :alt: codecov.io

.. |docs| image:: https://readthedocs.org/projects/blueetl/badge/?version=latest
   :target: https://blueetl.readthedocs.io/
   :alt: documentation status

.. |CodeQL| image:: https://github.com/BlueBrain/blueetl/actions/workflows/github-code-scanning/codeql/badge.svg
   :target: https://github.com/BlueBrain/blueetl/actions/workflows/github-code-scanning/codeql
   :alt: CodeQL

.. |PyPI| image:: https://github.com/BlueBrain/blueetl/actions/workflows/publish-sdist.yml/badge.svg
   :target: https://pypi.org/project/blueetl/
   :alt: PyPI

.. |DOI| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.10286540.svg
   :target: https://doi.org/10.5281/zenodo.10286540
   :alt: DOI

.. local-substitutions

.. |banner| image:: https://raw.githubusercontent.com/BlueBrain/blueetl/main/doc/source/_images/BlueETL.jpeg
